- X_dim
A vector containing the number of predictors in each block.
- X_weight
A list containing the weights of predictors for different
blocks in different PLS components.
- X_score
A list containing the scores of samples in different blocks
in different PLS components.
- X_loading
A list containing the loadings of predictors for different
blocks in different PLS components.
- X_super_weight
A matrix containing the super weights of different
blocks for different PLS components.
- X_super_score
A matrix containing the super scores of samples for
different PLS components.
- Y_weight
A matrix containing the weights of outcome for different
PLS components.
- Y_score
A matrix containing the scores of outcome for different
PLS components.
- X_col_mean
A matrix containing the mean of each predictor for scaling.
- Y_col_mean
The mean of outcome matrix for scaling.
- X_col_sd
A matrix containing the standard deviation of each predictor
for scaling. Predictor with sd = 0 will be set to 1.
- Y_col_sd
The standard deviation of outcome matrix for scaling.
- center
A logical value indicating whether mean center is
implemented for X.matrix and Y.matrix.
- scale
A logical value indicating whether scale is implemented for
X.matrix and Y.matrix.